Struct amazon_sp_aplus_content::models::standard_multiple_image_text_module::StandardMultipleImageTextModule
source · [−]pub struct StandardMultipleImageTextModule {
pub blocks: Option<Vec<StandardImageTextCaptionBlock>>,
}Expand description
StandardMultipleImageTextModule : Standard images with text, presented one at a time. The user clicks on thumbnails to view each block.
Fields
blocks: Option<Vec<StandardImageTextCaptionBlock>>Implementations
sourceimpl StandardMultipleImageTextModule
impl StandardMultipleImageTextModule
sourcepub fn new() -> StandardMultipleImageTextModule
pub fn new() -> StandardMultipleImageTextModule
Standard images with text, presented one at a time. The user clicks on thumbnails to view each block.